==> hibernate-core-4.1.4.Final-sources.jar: org/hibernate/type/XmlRepresentableType.java <==
/*
 * Hibernate, Relational Persistence for Idiomatic Java
 *
 * Copyright (c) 2010, Red Hat Inc. or third-party contributors as
 * indicated by the @author tags or express copyright attribution
 * statements applied by the authors.  All third-party contributions are
 * distributed under license by Red Hat Inc.
 *
 * This copyrighted material is made available to anyone wishing to use, modify,
 * copy, or redistribute it subject to the terms and conditions of the GNU
 * Lesser General Public License, as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
 * for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this distribution; if not, write to:
 * Free Software Foundation, Inc.
 * 51 Franklin Street, Fifth Floor
 * Boston, MA  02110-1301  USA
 */
package org.hibernate.type;
import org.hibernate.HibernateException;
import org.hibernate.engine.spi.Mapping;
import org.hibernate.engine.spi.SessionFactoryImplementor;

/**
 * Additional, optional contract for types whose values can be represented as XML text (either as attribute or
 * element value).
 *
 * @author Steve Ebersole
 */
public interface XmlRepresentableType<T> {
	public String toXMLString(T value, SessionFactoryImplementor factory) throws HibernateException;

	public T fromXMLString(String xml, Mapping factory) throws HibernateException;
}

==> hibernate-core-4.2.6.Final-sources.jar: org/hibernate/type/XmlRepresentableType.java <==
/*
 * Hibernate, Relational Persistence for Idiomatic Java
 *
 * Copyright (c) 2010, Red Hat Inc. or third-party contributors as
 * indicated by the @author tags or express copyright attribution
 * statements applied by the authors.  All third-party contributions are
 * distributed under license by Red Hat Inc.
 *
 * This copyrighted material is made available to anyone wishing to use, modify,
 * copy, or redistribute it subject to the terms and conditions of the GNU
 * Lesser General Public License, as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
 * for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this distribution; if not, write to:
 * Free Software Foundation, Inc.
 * 51 Franklin Street, Fifth Floor
 * Boston, MA  02110-1301  USA
 */
package org.hibernate.type;

import org.hibernate.HibernateException;
import org.hibernate.engine.spi.Mapping;
import org.hibernate.engine.spi.SessionFactoryImplementor;

/**
 * Additional, optional contract for types whose values can be represented as XML text (either as attribute or
 * element value).
 *
 * @author Steve Ebersole
 *
 * @deprecated To be removed in 5.  Use {@link StringRepresentableType} instead.  See Jira issues
 * <a href="https://hibernate.onjira.com/browse/HHH-7777">HHH-7777</a> and
 * <a href="https://hibernate.onjira.com/browse/HHH-7776">HHH-7776</a> for details.
 *
 * @see StringRepresentableType
 */
@Deprecated
public interface XmlRepresentableType<T> {
	public String toXMLString(T value, SessionFactoryImplementor factory) throws HibernateException;

	public T fromXMLString(String xml, Mapping factory) throws HibernateException;
}
